Crate ironfish_zkp

Crate ironfish_zkp 

Re-exports

pub use primitives::proof_generation_key::ProofGenerationKey;

Modules

constants
hex
pedersen_hash
Implementation of the Pedersen hash function used in Sapling.
primitives
proofs
redjubjub
Implementation of RedJubjub, a specialization of RedDSA to the Jubjub curve.
util

Structs

Diversifier
Nullifier
Typesafe wrapper for nullifier values.
PaymentAddress
A Sapling payment address.
SaplingNote
ViewingKey

Enums

Rseed
Enum for note randomness before and after ZIP 212.

Functions

group_hash
Produces a random point in the Jubjub curve. The point is guaranteed to be prime order and not the identity.