Re-exports
pub use primitives::proof_generation_key::ProofGenerationKey;
Modules
- constants
- hex
- pedersen_
hash - Implementation of the Pedersen hash function used in Sapling.
- primitives
- proofs
- redjubjub
- Implementation of RedJubjub, a specialization of RedDSA to the Jubjub curve.
- util
Structs
- Diversifier
- Nullifier
- Typesafe wrapper for nullifier values.
- Payment
Address - A Sapling payment address.
- Sapling
Note - Viewing
Key
Enums
Functions
- group_
hash - Produces a random point in the Jubjub curve. The point is guaranteed to be prime order and not the identity.